@@ -30,8 +30,14 @@
 #include "kcmhelpcenteradaptor.h"
 
 #include <KConfig>
+#include <KDebug>
+#include <KLocale>
+#include <KGlobal>
 #include <KAboutData>
 #include <KDialog>
+#include <KStandardDirs>
+#include <KProcess>
+#include <KApplication>
 #include <KTemporaryFile>
 #include <KUrlRequester>
 #include <KMessageBox>
@@ -47,14 +53,9 @@
 
 #include <unistd.h>
 #include <sys/types.h>
-#include <QStandardPaths>
 
 using namespace KHC;
 
-namespace {
-QLoggingCategory category("org.kde.khelpcenter");
-}
-
 IndexDirDialog::IndexDirDialog( QWidget *parent )
   : KDialog( parent )
 {
@@ -133,7 +134,7 @@ IndexProgressDialog::IndexProgressDialog( QWidget *parent )
 IndexProgressDialog::~IndexProgressDialog()
 {
   if ( !mLogView->isHidden() ) {
-    KConfigGroup cfg(KSharedConfig::openConfig(), "indexprogressdialog");
+    KConfigGroup cfg(KGlobal::config(), "indexprogressdialog");
     cfg.writeEntry( "size", size() );
   }
 }
@@ -194,7 +195,7 @@ void IndexProgressDialog::slotEnd()
 
 void IndexProgressDialog::toggleDetails()
 {
-  KConfigGroup cfg(KSharedConfig::openConfig(), "indexprogressdialog");
+  KConfigGroup cfg(KGlobal::config(), "indexprogressdialog");
   if ( mLogView->isHidden() ) {
     mLogLabel->show();
     mLogView->show();
@@ -238,7 +239,7 @@ KCMHelpCenter::KCMHelpCenter( KHC::SearchEngine *engine, QWidget *parent,
 
   setButtonGuiItem( KDialog::Ok, KGuiItem(i18n("Build Index")) );
 
-  mConfig = KSharedConfig::openConfig();
+  mConfig = KGlobal::config();
 
   DocMetaInfo::self()->scanMetaInfo();
 
@@ -247,17 +248,17 @@ KCMHelpCenter::KCMHelpCenter( KHC::SearchEngine *engine, QWidget *parent,
   QDBusConnection dbus = QDBusConnection::sessionBus();
   bool success = dbus.connect(QString(), "/kcmhelpcenter", dbusInterface, "buildIndexProgress", this, SLOT(slotIndexProgress()));
   if ( !success )
-    qWarning() << "connect D-Bus signal failed";
+    kError() << "connect D-Bus signal failed" << endl;
   success = dbus.connect(QString(), "/kcmhelpcenter", dbusInterface, "buildIndexError", this, SLOT(slotIndexError(const QString&)));
   if ( !success )
-    qWarning() << "connect D-Bus signal failed";
+    kError() << "connect D-Bus signal failed" << endl;
   KConfigGroup id( mConfig, "IndexDialog" );
   restoreDialogSize( id );
 }
 
 KCMHelpCenter::~KCMHelpCenter()
 {
-  KConfigGroup cg( KSharedConfig::openConfig(), "IndexDialog" );
+  KConfigGroup cg( KGlobal::config(), "IndexDialog" );
   KDialog::saveDialogSize( cg );
 }
 
@@ -312,7 +313,7 @@ void KCMHelpCenter::defaults()
 
 bool KCMHelpCenter::save()
 {
-  qCDebug(category) << "KCMHelpCenter::save()";
+  kDebug(1401) << "KCMHelpCenter::save()";
 
   if ( !QFile::exists( Prefs::indexDirectory() ) ) {
     KMessageBox::sorry( this,
@@ -335,8 +336,8 @@ void KCMHelpCenter::load()
   const DocEntry::List &entries = DocMetaInfo::self()->docEntries();
   DocEntry::List::ConstIterator it;
   for( it = entries.begin(); it != entries.end(); ++it ) {
-//    qCDebug(category) << "Entry: " << (*it)->name() << " Indexer: '"
-//              << (*it)->indexer() << "'";
+//    kDebug(1401) << "Entry: " << (*it)->name() << " Indexer: '"
+//              << (*it)->indexer() << "'" << endl;
     if ( mEngine->needsIndex( *it ) ) {
       ScopeItem *item = new ScopeItem( mListView, *it );
       item->setOn( (*it)->searchEnabled() );
@@ -370,12 +371,12 @@ void KCMHelpCenter::updateStatus()
 
 bool KCMHelpCenter::buildIndex()
 {
-  qCDebug(category) << "Build Index";
+  kDebug(1401) << "Build Index";
 
-  qDebug() << "IndexPath: '" << Prefs::indexDirectory() << "'";
+  kDebug() << "IndexPath: '" << Prefs::indexDirectory() << "'";
 
   if ( mProcess ) {
-    qWarning() << "Error: Index Process still running.";
+    kError() << "Error: Index Process still running." << endl;
     return false;
   }
 
@@ -386,13 +387,13 @@ bool KCMHelpCenter::buildIndex()
 
   mCmdFile = new KTemporaryFile;
   if ( !mCmdFile->open() ) {
-    qWarning() << "Error opening command file.";
+    kError() << "Error opening command file." << endl;
     deleteCmdFile();
     return false;
   }
 
   QTextStream ts ( mCmdFile );
-  qDebug() << "Writing to file '" << mCmdFile->fileName() << "'";
+  kDebug() << "Writing to file '" << mCmdFile->fileName() << "'";
 
   bool hasError = false;
 
@@ -431,7 +432,7 @@ bool KCMHelpCenter::buildIndex()
             indexer.replace( QLatin1String("%i" ), entry->identifier() );
             indexer.replace( QLatin1String( "%d" ), Prefs::indexDirectory() );
             indexer.replace( QLatin1String( "%p" ), entry->url() );
-            qDebug() << "INDEXER: " << indexer;
+            kDebug() << "INDEXER: " << indexer;
             ts << indexer << endl;
 
             int width = fm.width( entry->name() );
@@ -474,26 +475,26 @@ bool KCMHelpCenter::buildIndex()
 
 void KCMHelpCenter::startIndexProcess()
 {
-  qDebug() << "KCMHelpCenter::startIndexProcess()";
+  kDebug() << "KCMHelpCenter::startIndexProcess()";
 
   mProcess = new KProcess;
 #ifndef Q_WS_WIN
   if ( mRunAsRoot ) {
-    QString kdesu = QStandardPaths::findExecutable("kdesu");
+    QString kdesu = KStandardDirs::findExe("kdesu");
     if(kdesu.isEmpty()) {
-      qWarning() << "Failed to run index process as root - could not find kdesu";
+      kError() << "Failed to run index process as root - could not find kdesu";
     } else {
       *mProcess << kdesu;
       if(parentWidget()) {
         *mProcess << "--attach" <<  QString::number(parentWidget()->window()->winId());
-        qDebug() << "Run as root, attaching kdesu to winid " << QString::number(parentWidget()->window()->winId());
+        kDebug() << "Run as root, attaching kdesu to winid " << QString::number(parentWidget()->window()->winId());
       }
       *mProcess << "--";
     }
   }
 #endif
 
-  *mProcess << QStandardPaths::findExecutable("khc_indexbuilder"); //Note this is in libexec
+  *mProcess << KStandardDirs::findExe("khc_indexbuilder");
   *mProcess << mCmdFile->fileName();
   *mProcess << Prefs::indexDirectory();
 
@@ -507,7 +508,7 @@ void KCMHelpCenter::startIndexProcess()
 
   mProcess->start();
   if (!mProcess->waitForStarted()) {
-    qWarning() << "KCMHelpcenter::startIndexProcess(): Failed to start process.";
+    kError() << "KCMHelpcenter::startIndexProcess(): Failed to start process.";
     deleteProcess();
     deleteCmdFile();
   }
@@ -515,7 +516,7 @@ void KCMHelpCenter::startIndexProcess()
 
 void KCMHelpCenter::cancelBuildIndex()
 {
-  qDebug() << "cancelBuildIndex()";
+  kDebug() << "cancelBuildIndex()";
 
   deleteProcess();
   deleteCmdFile();
@@ -528,20 +529,20 @@ void KCMHelpCenter::cancelBuildIndex()
 
 void KCMHelpCenter::slotIndexFinished(int exitCode, QProcess::ExitStatus exitStatus)
 {
-  qDebug() << "KCMHelpCenter::slotIndexFinished()";
+  kDebug() << "KCMHelpCenter::slotIndexFinished()";
 
   if ( exitStatus == QProcess::NormalExit && exitCode == 2 ) {
     if ( mRunAsRoot ) {
-      qWarning() << "Insufficient permissions.";
+      kError() << "Insufficient permissions." << endl;
     } else {
-      qDebug() << "Insufficient permissions. Trying again as root.";
+      kDebug() << "Insufficient permissions. Trying again as root.";
       mRunAsRoot = true;
       deleteProcess();
       startIndexProcess();
       return;
     }
   } else if ( exitStatus != QProcess::NormalExit || exitCode != 0 ) {
-    qDebug() << "KProcess reported an error.";
+    kDebug() << "KProcess reported an error.";
     KMessageBox::error( this, i18n("Failed to build index.") );
   } else {
     mConfig->group( "Search" ).writeEntry( "IndexExists", true );
@@ -583,7 +584,7 @@ void KCMHelpCenter::slotIndexProgress()
   if( !mProcess )
     return;
 
-  qDebug() << "KCMHelpCenter::slotIndexProgress()";
+  kDebug() << "KCMHelpCenter::slotIndexProgress()";
 
   updateStatus();
 
@@ -595,7 +596,7 @@ void KCMHelpCenter::slotIndexError( const QString &str )
   if( !mProcess )
     return;
 
-  qDebug() << "KCMHelpCenter::slotIndexError()";
+  kDebug() << "KCMHelpCenter::slotIndexError()";
 
   KMessageBox::sorry( this, i18n("Error executing indexing build command:\n%1",
       str ) );
@@ -658,7 +659,7 @@ void KCMHelpCenter::slotOk()
 
 void KCMHelpCenter::slotProgressClosed()
 {
-  qDebug() << "KCMHelpCenter::slotProgressClosed()";
+  kDebug() << "KCMHelpCenter::slotProgressClosed()";
 
   if ( mIsClosing ) accept();
 }
